@@ -18,7 +18,7 @@ from DateTime import DateTime
 
 from Products.CMFCore.permissions import ManagePortal, View, ModifyPortalContent, AccessContentsInformation, ListFolderContents
 from Products.CMFCore.utils import getToolByName
-from Products.ATContentTypes.content.folder import ATBTreeFolder
+from Products.ATContentTypes.content.folder import ATBTreeFolder, ATFolder
 from Products.Archetypes.utils import make_uuid
 from Products.ATContentTypes.content.base import ATCTContent
 from Products.ATReferenceBrowserWidget.ATReferenceBrowserWidget import ReferenceBrowserWidget
@@ -57,13 +57,13 @@ class ECardsSavedFolder(ATBTreeFolder):
 registerType(ECardsSavedFolder, PROJECTNAME)
 
 
-class ECardsFolder(ATBTreeFolder):
+class ECardsFolder(ATFolder):
     """ Container for Ecards """
 
     content_icon = 'ecardsfolder_icon.gif'
     global_allow = 0
 
-    schema = ATBTreeFolder.schema.copy() + \
+    schema = ATFolder.schema.copy() + \
           Schema((
 
                IntegerField('columns',
@@ -127,7 +127,7 @@ class ECardsFolder(ATBTreeFolder):
         return [b.getObject() for b in result]
 
     def manage_afterAdd(self, item,  container):
-        ATBTreeFolder.manage_afterAdd(self, item, container)
+        super(ECardsFolder, self).manage_afterAdd(item, container)
         if not FOLDER_ID in self.objectIds():
             self.invokeFactory('ECardsSavedFolder', FOLDER_ID)
             folder  = self[FOLDER_ID]
